@@ -5,7 +5,7 @@
 
 class QPushButton;
 class QHBoxLayout;
-
+class QTextEdit;
 class MainWindow;
 
 class Launcher : public QWidget
@@ -18,10 +18,13 @@ public:
 
 public slots:
 	void startXTerm(void);
+	void showHelp(void);
 
 private:
         QHBoxLayout *m_layout;
- 	enum { PASSWD_BUTTON = 0, XTERM_BUTTON, METHER_BUTTON, NUM_BUTTONS };
+ 	enum { PASSWD_BUTTON = 0, XTERM_BUTTON, METHER_BUTTON, HELP_BUTTON,
+	       NUM_BUTTONS };
         QPushButton *m_buttons[NUM_BUTTONS];
+	QTextEdit *m_helpwindow;
 };
 #endif
