@@ -21,9 +21,12 @@ public:
 
 public slots:
 	void dataAvailable(int exitCode);
-	void updateInterfaces(void);
+	void updateInterfaces(int);
 	void setEditButtonEnabled(bool enabled);
 
+signals:
+	void config_ifaces(void);
+
 private:
 	QGridLayout * m_layout;
 	MainWindow *m_main;
