@@ -19,7 +19,7 @@ UsbManage::UsbManage(MainWindow *main)
 	m_buttons[LOAD_E_BUTTON] = new QPushButton(tr("Windows\nNetwork"));
 	m_buttons[LOAD_N_BUTTON] = new QPushButton(tr("Unix\nNetwork"));
 	m_buttons[LOAD_F_BUTTON] = new QPushButton(tr("Mass\nStorage"));
-	m_buttons[CLOSE_BUTTON] = new QPushButton(tr("Close\n"));
+	m_buttons[CLOSE_BUTTON] = new QPushButton(tr("Close"));
 	m_txt = new QLabel(tr("USB module in use"));
 	m_module = new QLabel(tr("None"));
 
