@@ -27,7 +27,7 @@ public slots:
 	void close(void);
 
 signals:
-	void done(void);
+	void done(int ec);
 
 private:
 	MainWindow *m_main;
@@ -40,5 +40,6 @@ private:
         QPushButton *m_buttons[NUM_BUTTONS];
 	QLabel *m_txt;
 	QLabel *m_module;
+	bool m_conf_usb_iface;
 };
 #endif
